%define shortname redhat-ds
%define pkgname   dirsrv
%define dist	.el5dsrv

Summary:          Red Hat Directory Server (base)
Name:             redhat-ds-base
Version:          8.2.4
Release:          1%{?dist}
License:          GPLv2 with exceptions
URL:              http://www.redhat.com/directory_server/
Group:            System Environment/Daemons
BuildRoot:        %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:    nspr-devel >= 4.6.4.1
BuildRequires:    nss-devel >= 3.11.4
BuildRequires:    svrcore-devel >= 4.0.3
BuildRequires:    mozldap-devel >= 6.0.4
BuildRequires:    db4-devel >= 4.2.52
BuildRequires:    cyrus-sasl-devel >= 2.1.19
BuildRequires:    icu >= 3.4
BuildRequires:    libicu-devel >= 3.4
BuildRequires:    pcre-devel >= 6.6
# The following are needed to build the snmp ldap-agent
BuildRequires:    net-snmp-devel >= 5.1.2
%ifnarch sparc sparc64 ppc ppc64
BuildRequires:    lm_sensors-devel
%endif
BuildRequires:    zlib-devel
BuildRequires:    openssl-devel
BuildRequires:    tcp_wrappers
BuildRequires:    libselinux-devel
# the following is for the pam passthru auth plug-in
BuildRequires:    pam-devel

# the following are needed for some of our scripts
Requires:         mozldap-tools
Requires:         perl-Mozilla-LDAP

# this is needed to setup SSL if you are not using the
# administration server package
Requires:         nss-tools

# these are not found by the auto-dependency method
# they are required to support the mandatory LDAP SASL mechs
Requires:	      cyrus-sasl-gssapi
Requires:	      cyrus-sasl-md5

# this is needed for verify-db.pl
Requires:             db4-utils

# for the init script
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig
Requires(preun): /sbin/service

Source0:          %{name}-%{version}.tar.bz2
Source1:          %{name}-devel.README

%description
Red Hat Directory Server is an LDAPv3 compliant server.  The base package includes
the LDAP server and command line utilities for server administration.

%package          devel
Summary:          Development libraries for Red Hat Directory Server
Group:            Development/Libraries
Requires:         %{name} = %{version}-%{release}
Requires:         mozldap-devel

%description      devel
Development Libraries and headers for the Red Hat Directory Server base package.


%prep
%setup -q -n %{name}-%{version}
cp %{SOURCE1} README.devel


%build
%configure --enable-ldapi --enable-autobind --with-pcre

# Generate symbolic info for debuggers
export XCFLAGS=$RPM_OPT_FLAGS

%ifarch x86_64 ppc64 ia64 s390x sparc64
export USE_64=1
%endif

make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT 

make DESTDIR="$RPM_BUILD_ROOT" install

mkdir -p $RPM_BUILD_ROOT/var/log/%{pkgname}
mkdir -p $RPM_BUILD_ROOT/var/lib/%{pkgname}
mkdir -p $RPM_BUILD_ROOT/var/lock/%{pkgname}
mkdir -p $RPM_BUILD_ROOT%{_includedir}/%{pkgname}

#remove libtool and static libs
rm -f $RPM_BUILD_ROOT%{_libdir}/%{pkgname}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/%{pkgname}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/%{pkgname}/plugins/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/%{pkgname}/plugins/*.la

install -p -m 644 ldap/servers/slapd/slapi-plugin.h $RPM_BUILD_ROOT%{_includedir}/%{pkgname}/
install -p -m 644 ldap/servers/plugins/replication/winsync-plugin.h $RPM_BUILD_ROOT%{_includedir}/%{pkgname}/

# make sure perl scripts have a proper shebang 
sed -i -e 's|#{{PERL-EXEC}}|#!/usr/bin/perl|' $RPM_BUILD_ROOT%{_datadir}/%{pkgname}/script-templates/template-*.pl

%clean
rm -rf $RPM_BUILD_ROOT

%post -p <lua>
os.execute('/sbin/chkconfig --add %{pkgname}')
os.execute('/sbin/ldconfig')
os.execute('/sbin/chkconfig --add %{pkgname}-snmp')
-- since posttrans is not passed the upgrade status, we get
-- it here
if (arg[2] > 1) or %{pkgname}_exists then
--    print("in %{pkgname} post - upgrading")
    %{pkgname}_upgrading = true
else
--    print("in %{pkgname} post - installing")
    %{pkgname}_upgrading = false
end

%preun
if [ $1 = 0 ]; then
        /sbin/service %{pkgname} stop >/dev/null 2>&1 || :
        /sbin/service %{pkgname}-snmp stop >/dev/null 2>&1 || :
        /sbin/chkconfig --del %{pkgname}
        /sbin/chkconfig --del %{pkgname}-snmp
fi

%postun -p /sbin/ldconfig

%posttrans -p <lua>
if %{pkgname}_upgrading then
    instbase = "%{_sysconfdir}/%{pkgname}"
--    print("posttrans - upgrading - looking for instances in "..instbase)
-- find all instances
    instances = {} -- instances that require a restart after upgrade
    for dir in posix.files(instbase) do
--        print("dir="..dir)
        if string.find(dir,"^slapd-") and not string.find(dir,"\.removed$") then
            inst = string.gsub(dir,"^slapd[-]", "")
--            print("found instance "..inst.." getting status")
            rc = os.execute('/sbin/service %{pkgname} status '..inst..' >/dev/null 2>&1')
-- if instance is running, we must restart it after upgrade
            if rc == 0 then
                instances[inst] = inst
--                print("instance "..inst.." is running")
--            else
--                print("instance "..inst.." is shutdown")
            end
        end
    end
-- shutdown all instances
--    print("shutting down all instances . . .")
    os.execute('/sbin/service %{pkgname} stop > /dev/null 2>&1')
-- do the upgrade
--    print("upgrading instances . . .")
    os.execute('%{_sbindir}/setup-ds.pl -l /dev/null -u -s General.UpdateMode=offline > /dev/null 2>&1')
-- restart instances that require it
    for inst,dummy in pairs(instances) do
--        print("restarting instance "..inst)
        os.execute('/sbin/service %{pkgname} start '..inst..' >/dev/null 2>&1')
    end
-- restart the snmp subagent if needed
    os.execute('/sbin/service %{pkgname}-snmp condrestart > /dev/null 2>&1')
end

%files
%defattr(-,root,root,-)
%doc LICENSE EXCEPTION
%dir %{_sysconfdir}/%{pkgname}
%dir %{_sysconfdir}/%{pkgname}/schema
%config(noreplace)%{_sysconfdir}/%{pkgname}/schema/*.ldif
%dir %{_sysconfdir}/%{pkgname}/config
%config(noreplace)%{_sysconfdir}/%{pkgname}/config/slapd-collations.conf
%config(noreplace)%{_sysconfdir}/%{pkgname}/config/certmap.conf
%config(noreplace)%{_sysconfdir}/%{pkgname}/config/template-initconfig
%config(noreplace)%{_sysconfdir}/%{pkgname}/config/ldap-agent.conf
%config(noreplace)%{_sysconfdir}/sysconfig/%{pkgname}
%{_datadir}/%{pkgname}
%{_initrddir}/%{pkgname}
%{_initrddir}/%{pkgname}-snmp
%{_bindir}/*
%{_sbindir}/*
%dir %{_libdir}/%{pkgname}
%{_libdir}/%{pkgname}/*.so.*
%{_libdir}/%{pkgname}/perl
%dir %{_libdir}/%{pkgname}/plugins
%{_libdir}/%{pkgname}/plugins/*.so
%dir %{_localstatedir}/lib/%{pkgname}
%dir %{_localstatedir}/log/%{pkgname}
%dir %{_localstatedir}/lock/%{pkgname}
%{_mandir}/man1/*
%{_mandir}/man8/*

%files devel
%defattr(-,root,root,-)
%doc LICENSE EXCEPTION README.devel
%{_includedir}/%{pkgname}
%{_libdir}/%{pkgname}/*.so

%changelog
* Fri Jan 28 2011 Nathan Kinder <nkinder@redhat.com> - 8.2.4-1.el5dsrv
- Bug 666076 - Crash with multiple simple paged searches
- Bug 671199 - Fix incorrect permissions on rundir
- Bug 672468 - Avoid empty path elements in library search paths
- pulled from git tag Directory_Server_8_2_Errata_Candidate_10610_20110128

* Thu Dec 16 2010 Nathan Kinder <nkinder@redhat.com> - 8.2.3-2.el5dsrv
- Bug 663597 - Memory leaks in normalization code
- pulled from git tag Directory_Server_8_2_Errata_Candidate_10382_20101216

* Thu Dec  9 2010 Nathan Kinder <nkinder@redhat.com> - 8.2.3-1.el5dsrv
- Bug 614511 - Null pointer dereferences issues in DN normalization
- Bug 640027 - Naming attribute with a special char sequence parsing bug
- Bug 641944 - Improve handling for CN's which contain a comma followed by a space
- pulled from git tag Directory_Server_8_2_Errata_Candidate_10382_20101209

* Wed Oct 26 2010 Noriko Hosoi <nhosoi@redhat.com> - 8.2.2-1.el5dsrv
- Bug 644608 - RHDS 8.1->8.2 upgrade fails to properly migrate ACIs
- pulled from git tag Directory_Server_8_2_Errata_Candidate_10193_20101026

* Wed Oct 22 2010 Noriko Hosoi <nhosoi@redhat.com> - 8.2.1-2.el5dsrv
- Bug 644608 - RHDS 8.1->8.2 upgrade fails to properly migrate ACIs
- pulled from git tag Directory_Server_8_2_Errata_Candidate_20101022

* Wed Sep  1 2010 Nathan Kinder <nkinder@redhat.com> - 8.2.1-1.el5dsrv
- Bug 612264 - ACI issue with (targetattr='userPassword')
- pulled from git tag Directory_Server_8_2_Errata_9930_20100901

* Wed Jul 28 2010 Noriko Hosoi <nhosoi@redhat.com> - 8.2.0-13.el5dsrv
- Bug 619229  - Upgrading sub suffix under non-normalized suffix disappears
- pulled from git tag Directory_Server_8_2_Candidate_20100728

* Thu Jul 22 2010 Rich Megginson <rmeggins@redhat.com> - 8.2.0-12.el5dsrv
- Bug 617013  - repl-monitor.pl use cpu upto 90%
- pulled from git tag Directory_Server_8_2_Candidate_20100722

* Wed Jul 21 2010 Noriko Hosoi <nhosoi@redhat.com> - 8.2.0-11.el5dsrv
- Bug 612771 - RHDS 8.1 accepts 2 identical entries with different DN formats (attachment id=433283) 
- pulled from git tag Directory_Server_8_2_Candidate_20100721

* Tue Jul 20 2010 Noriko Hosoi <nhosoi@redhat.com> - 8.2.0-10.el5dsrv
- fixed the wrong branding applied to the previous build
- pulled from git tag Directory_Server_8_2_Candidate_20100719

* Mon Jul 19 2010 Noriko Hosoi <nhosoi@redhat.com> - 8.2.0-9.el5dsrv
- Bug 612771 - RHDS 8.1/389 v1.2.5 accepts 2 identical entries with different DN formats
- Bug 616135 - Upgrade failure on Solaris : tar: db/NetscapeRoot/{DBVERSION,*.db4}: No such file or directory
- pulled from git tag Directory_Server_8_2_Candidate_20100719

* Thu Jul 15 2010 Noriko Hosoi <nhosoi@redhat.com> - 8.2.0-8.el5dsrv
- Bug 612771 - RHDS 8.1/389 v1.2.5 accepts 2 identical entries with different DN formats
- pulled from git tag Directory_Server_8_2_Candidate_20100715

* Fri Jul  9 2010 Nathan Kinder <nkinder@redhat.com> - 8.2.0-7.el5dsrv
- Bug 612242 - membership change on DS does not show on AD
- pulled from git tag Directory_Server_8_2_Candidate_20100709

* Wed Jul  7 2010 Rich Megginson <rmeggins@redhat.com> - 8.2.0-6.el5dsrv
- Bug 470684 - Pam_passthru plugin doesn't verify account activation
- pulled from git tag Directory_Server_8_2_Candidate_20100707

* Thu Jul  1 2010 Rich Megginson <rmeggins@redhat.com> - 8.2.0-5.el5dsrv
- removed GER null deref patch - patch committed upstream
- pulled from git tag Directory_Server_8_2_Candidate_20100701

* Wed Jun 23 2010 Rich Megginson <rmeggins@redhat.com> - 8.2.0-4.el5dsrv
- updated GER null deref patch
- Bug 604453 - SASL Stress and Server crash: Program quits with the assertion from PR_Poll
- 606920 - anonymous resource limit - nstimelimit - also applied to "cn=directory manager"
- 605827 - In-place upgrade: upgrade dn format should not run in setup-ds-admin.pl online mode
- pulled from git tag Directory_Server_8_2_Candidate_20100623

* Wed Jun 16 2010 Rich Megginson <rmeggins@redhat.com> - 8.2.0-3.el5dsrv
- Added GER null deref patch
- Bug 604263 - Fix memory leak when password change is rejected
- pulled from git tag Directory_Server_8_2_Candidate_20100616

* Thu Jun 10 2010 Nathan Kinder <nkinder@redhat.com> - 8.2.0-2.el5dsrv
- Added lua posttrans scriptlet to upgrade instances

* Tue Jun 8 2010 Nathan Kinder <nkinder@redhat.com> - 8.2.0-1.el5dsrv
- Added man pages for start-dirsrv and related commands
- git tag Directory_Server_8_2_Candidate_20100608

* Mon Jun 7 2010 Nathan Kinder <nkinder@redhat.com> - 8.2.0-0.2.el5dsrv
- Several bug fixes for 8.2 candidate
- CVS tag Directory_Server_8_2_Candidate_20100607

* Mon Feb 8 2010 Nathan Kinder <nkinder@redhat.com> - 8.2.0-0.1.el5dsrv
- Added SNMP subagent config template and init script
- Added instance specific initconfig template.
- Enabled bitwise plug-in
- Enabled pam-passthru plug-in
- Added "--with-pcre" to configure line
- Added BuildRequires pcre-devel

* Thu Jan 7 2010 Nathan Kinder <nkinder@redhat.com> - 8.1.1-1.el5dsrv
- Resolves: Bug 387681
- Description: map AD tombstone DNs containing commas properly
- CVS tag Directory_Server_8_1_Errata_2010-9317

* Tue Apr 21 2009 Nathan Kinder <nkinder@redhat.com> - 8.1.0-14.el5dsrv
- Resolves: Bug 496836
- Description: corrected semaphore name used by SNMP subagent
- CVS tag Directory_Server_8_1_Candidate_20090421

* Thu Apr 16 2009 Noriko Hosoi <nhosoi@redhat.com> - 8.1.0-0.13.el5dsrv
- Resolves: Bug 475338
- Description: LOG: the intenal type of maxlogsize, maxdiskspace and minfreespace should be 64-bit integer (comment #23)
- CVS tag Directory_Server_8_1_Candidate_20090416

* Thu Apr 16 2009 Rich Megginson <rmeggins@redhat.com> - 8.1.0-0.12.el5dsrv
- used incorrect dist tag

* Thu Apr 16 2009 Rich Megginson <rmeggins@redhat.com> - 8.1.0-0.11.el5dsrv
- Resolves: Bug 475338
- Description: LOG: the intenal type of maxlogsize, maxdiskspace and minfreespace should be 64-bit integer
- CVS tag Directory_Server_8_1_Candidate_20090416

* Thu Apr 02 2009 Nathan Kinder <nkinder@redhat.com> - 8.1.0-0.10.el5dsrv
- Fix return status for init script.

* Wed Apr 1 2009 Kevin Wright <kwright@redhat.com> - 8.1.0-0.9.el5dsrv
- Respin using DSRV-8-RHEL5 branch instead of DSRV-8_1-RHEL5.

* Tue Mar 31 2009 Kevin Wright <kwright@redhat.com> - 8.1.0-0.8.el5dsrv
- Initial brew build for 8.1.0

* Fri Jan 30 2009 Nathan Kinder <nkinder@redhat.com> - 8.1.0-0.7.el5dsrv
- Made devel package depend on mozldap-devel

* Mon Oct 30 2008 Noriko Hosoi <nhosoi@redhat.com> - 8.1.0-0.6.el5dsrv
- added db4-utils to Requires for verify-db.pl

* Mon Oct 13 2008 Noriko Hosoi <nhosoi@redhat.com> - 8.1.0-0.5.el5dsrv
- Enabled LDAPI autobind

* Tue Aug  5 2008 Rich Megginson <rmeggins@redhat.com> - 8.1.0-0.4.el5dsrv
- added winsync-plugin.h to the devel package

* Tue Jul 29 2008 Nathan Kinder <nkinder@redhat.com> - 8.1.0-0.3.el5dsrv
- Enabled LDAPI and the DNA plug-in

* Thu Jul 17 2008 Rich Megginson <rmeggins@redhat.com> - 8.1.0-0.2.el5dsrv
- added man pages

* Tue Apr 22 2008 Noriko Hosoi <nhosoi@redhat.com> - 8.1.0-0.1.el5dsrv
- initial version for RHDS 8.1.0
- removed "--disable-ldapi" from configure parameters

* Fri Apr 18 2008 Noriko Hosoi <nhosoi@redhat.com> - 8.0.0-15.el5dsrv
- Fix memory leaks in extensible filter code

* Mon Mar 03 2008 Nathan Kinder <nkinder@redhat.com> - 8.0.0-14.el5dsrv
- Rebuild.

* Mon Mar 03 2008 Nathan Kinder <nkinder@redhat.com> - 8.0.0-13.el5dsrv
- Fix fractional replication between masters.

* Tue Nov 06 2007 Margaret Lum <mlum@redhat.com> - 8.0.0-11.el5dsrv
- Build officially in Brew.

* Wed Oct 17 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-6.el5dsrv
- remove /var/tmp/dirsrv from package

* Fri Oct  5 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-5.el5dsrv
- The file /etc/sysconfig/dirsrv has been added to the package

* Thu Aug 16 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-4.el5dsrv
- several migration fixes
- fix usage of open() with O_CREAT and db4->open() calls
- update License to GPLv2 with exceptions as per Fedora

* Fri Aug 10 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-3
- Change pathnames to use the pkgname macro which is dirsrv

* Fri Aug 10 2007 Noriko Hosoi <nhosoi@redhat.com> - 8.0.0-2
- upgraded mozldap version to 6.0.4

* Tue Jul 24 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-1
- removed fedora-isms, cvsdate

* Tue Jul 24 2007 Margaret Lum <mlum@redhat.com> - 8.0.0-0.3.el5dsrv
- Adding back in cvsdate

* Mon Jul 23 2007 Margaret Lum <mlum@redhat.com> - 8.0.0-0.2.el5dsrv
- Use %{?dist} defined in buildsys-macros

* Mon Jul 23 2007 Rich Megginson <rmeggins@redhat.com> - 8.0.0-0.1.20070723
- initial version based on fedora-ds-base.spec
